Lage/Redigere bilde

Lage/Redigere bilde | IF

Funksjonen "Lage/Redigere bilde" åpner et nytt vindu som ser ut som bildet nedenfor.
I dette vinduet skriver du inn URL:en til bildet du vil lenke til samt en bildebeskrivelse, denne beskrivelsen kommer til å vises som en alternativ tekst til bildet.
Feltforklaring:

Bildets URL | URL/søkevei til bildet.
Bildets beskrivelse | Bildets beskrivelse, denne beskrivelsen kommer til å vises som en alternativ tekst til bildet.
Dimensjoner | Bildets bredde og høyde.
Justering | Bildets justering, kan være anvendelig når man vil at tekst skal flyte rundt bildet.
Ramme | Bilderammens bredde.
Vertikalt tomrom | Vertikalt tomrom , kan væra anvendelig når man vil at tekst skal flyte rundt bildet.
Horisontalt tomrom | Horisontalt tomrom, kan være anvendelig når man vil at tekst skal flyte rundt bildet.

Gå til: Innholdsoversikt | Toppen